@@ -10,6 +10,7 @@ from .resources.balances import BalanceRecord
 from .resources.credit_report import CreditReport
 from .resources.institutions import Institution
 from .resources.transactions import TransactionRecord
+from .resources.users import User
 
 __all__ = (
     "AsyncClient",
@@ -21,4 +22,5 @@ __all__ = (
     "CreditReport",
     "Institution",
     "TransactionRecord",
+    "User",
 )
