@@ -1,47 +1,32 @@
 import asyncio
 from abc import ABC
 from datetime import datetime
-from typing import List, Optional, Sequence, Set
+from typing import Any, Dict, List, Optional, Sequence
 
-from pydantic import BaseModel, validate_arguments
+from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
+from .errors import ServerError
+from .retry import retry_policy
 
 PATH = "/users/{user_uuid}/institutions/{institution_id}/alerts"
 
-
-class Alert(BaseModel):
-    smslog_id: str
-    ts: int
-    smslog_body: str
-    labels: Set[str]
-
-
-class AlertsMeta(BaseModel):
-    page: int
-    utc_starttime: Optional[datetime] = None
-    utc_endtime: Optional[datetime] = None
-    institution_id: str
-    user_uuid: str
-    total_alerts_count: int
-    max_pages: int
-    client_uuid: str
-
-
-class AlertsResponse(BaseModel):
-    meta: AlertsMeta
-    alerts: List[Alert]
-
-    class Config:
-        fields = {"meta": "_meta"}
+Alert = Dict[str, Any]
+AlertsMeta = Dict[str, Any]
+AlertsResponse = Dict[str, Any]
 
 
 class BaseAlertsResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
+    @retry_policy(
+        max_retry_count=4,
+        max_retry_interval_seconds=10,
+        retryable_exceptions=[ServerError],
+    )
     async def _get_page(
         self,
         user_uuid: str,
@@ -62,8 +47,11 @@ class BaseAlertsResource(ABC):
                 ),
             )
 
+        if response.status_code == 500:
+            raise ServerError(response.text)
+
         assert response.status_code == 200, response.text
-        return AlertsResponse(**response.json())
+        return response.json()  # type: ignore
 
     @validate_arguments
     @cache
@@ -84,7 +72,7 @@ class BaseAlertsResource(ABC):
             labels=labels,
             page=page or 1,
         )
-        max_pages = response.meta.max_pages
+        max_pages = response["_meta"]["max_pages"]
         if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
@@ -102,7 +90,7 @@ class BaseAlertsResource(ABC):
         else:
             responses = (response,)
 
-        return [alert for response in responses for alert in response.alerts]
+        return [alert for response in responses for alert in response["alerts"]]
 
 
 class AsyncAlertsResource(BaseAlertsResource):
