@@ -1,55 +1,33 @@
 import asyncio
 from abc import ABC
 from datetime import datetime
-from typing import List, Optional, Sequence, Set
+from typing import Any, Dict, List, Optional, Sequence
 
-from pydantic import BaseModel, validate_arguments
+from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
+from .errors import ServerError
+from .retry import retry_policy
 
 PATH = "/users/{user_uuid}/institutions/{institution_id}/balances"
 
-
-class BalanceRecord(BaseModel):
-    description: Optional[str]
-    balance: float
-    ts: int
-    currency: Optional[str]
-    labels: Set[str]
-    account_id: str
-    account_type: Optional[str]
-
-
-class BalancesMeta(BaseModel):
-    account_types: Optional[str]
-    labels: Optional[str]
-    page: int
-    utc_starttime: Optional[datetime] = None
-    utc_endtime: Optional[datetime] = None
-    total_balances_count: int
-    max_pages: int
-
-
-class BalancesAccount(BaseModel):
-    account_id: str
-    account_type: Optional[str]
-    records: List[BalanceRecord]
-
-
-class BalancesResponse(BaseModel):
-    meta: BalancesMeta
-    balances: List[BalancesAccount]
-
-    class Config:
-        fields = {"meta": "_meta"}
+BalanceRecord = Dict[str, Any]
+BalancesMeta = Dict[str, Any]
+BalancesAccount = Dict[str, Any]
+BalancesResponse = Dict[str, Any]
 
 
 class BaseBalancesResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
+    @retry_policy(
+        max_retry_count=4,
+        max_retry_interval_seconds=10,
+        retryable_exceptions=[ServerError],
+    )
     async def _get_page(
         self,
         user_uuid: str,
@@ -72,8 +50,11 @@ class BaseBalancesResource(ABC):
                 ),
             )
 
+        if response.status_code == 500:
+            raise ServerError(response.text)
+
         assert response.status_code == 200, response.text
-        return BalancesResponse(**response.json())
+        return response.json()  # type: ignore
 
     @validate_arguments
     @cache
@@ -96,7 +77,7 @@ class BaseBalancesResource(ABC):
             account_types=account_types,
             page=page or 1,
         )
-        max_pages = response.meta.max_pages
+        max_pages = response["_meta"]["max_pages"]
         if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
@@ -118,8 +99,8 @@ class BaseBalancesResource(ABC):
         return [
             record
             for response in responses
-            for balance_account in response.balances
-            for record in balance_account.records
+            for balance_account in response["balances"]
+            for record in balance_account["records"]
         ]
 
 
