@@ -7,6 +7,8 @@ from pydantic import validate_arguments
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
+from .errors import ServerError
+from .retry import retry_policy
 
 PATH = "/creditreport/alternative"
 
@@ -20,6 +22,11 @@ class BaseCreditReportResource(ABC):
 
     @validate_arguments
     @cache
+    @retry_policy(
+        max_retry_count=4,
+        max_retry_interval_seconds=10,
+        retryable_exceptions=[ServerError],
+    )
     async def _get(
         self, user_uuid: str, utc_time: Optional[datetime] = None
     ) -> CreditReport:
@@ -32,6 +39,9 @@ class BaseCreditReportResource(ABC):
                 ),
             )
 
+        if response.status_code == 500:
+            raise ServerError(response.text)
+
         assert response.status_code == 200, response.text
         credit_report: CreditReport = response.json()
         return credit_report
