@@ -1,33 +1,16 @@
 from abc import ABC
-from typing import List, Optional
+from typing import Any, Dict, List
 
-from pydantic import BaseModel, validate_arguments
+from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 
 PATH = "/users/{user_uuid}/institutions"
 
-
-class Institution(BaseModel):
-    institution_id: str
-    display_name: str
-    currency: Optional[str]
-    account_ids: List[str]
-    account_types: List[str]
-
-
-class InstitutionsMeta(BaseModel):
-    user_uuid: str
-    client_uuid: str
-
-
-class InstitutionsResponse(BaseModel):
-    meta: InstitutionsMeta
-    institutions: List[Institution]
-
-    class Config:
-        fields = {"meta": "_meta"}
+Institution = Dict[str, Any]
+InstitutionsMeta = Dict[str, Any]
+InstitutionsResponse = Dict[str, Any]
 
 
 class BaseInstitutionsResource(ABC):
@@ -41,7 +24,7 @@ class BaseInstitutionsResource(ABC):
             response = await session.get(PATH.format(user_uuid=user_uuid))
 
         assert response.status_code == 200, response.text
-        return InstitutionsResponse(**response.json()).institutions
+        return response.json()["institutions"]  # type: ignore
 
 
 class AsyncInstitutionsResource(BaseInstitutionsResource):
