@@ -1,57 +1,33 @@
 import asyncio
 from abc import ABC
 from datetime import datetime
-from typing import List, Optional, Sequence, Set
+from typing import Any, Dict, List, Optional, Sequence
 
-from pydantic import BaseModel, validate_arguments
+from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
+from .errors import ServerError
+from .retry import retry_policy
 
 PATH = "/users/{user_uuid}/institutions/{institution_id}/transactions"
 
-
-class TransactionRecord(BaseModel):
-    ts: int
-    description: Optional[str]
-    amount: float
-    impact: str
-    account_id: str
-    account_type: Optional[str]
-    currency: Optional[str]
-    labels: Set[str]
-
-
-class TransactionsMeta(BaseModel):
-    page: int
-    utc_starttime: Optional[datetime] = None
-    utc_endtime: Optional[datetime] = None
-    institution_id: str
-    user_uuid: str
-    total_transactions_count: int
-    max_pages: int
-    client_uuid: str
-
-
-class TransactionsAccount(BaseModel):
-    account_id: str
-    account_type: Optional[str]
-    records: List[TransactionRecord]
-
-
-class TransactionsResponse(BaseModel):
-    meta: TransactionsMeta
-    transactions: List[TransactionsAccount]
-
-    class Config:
-        fields = {"meta": "_meta"}
+TransactionRecord = Dict[str, Any]
+TransactionsMeta = Dict[str, Any]
+TransactionsAccount = Dict[str, Any]
+TransactionsResponse = Dict[str, Any]
 
 
 class BaseTransactionsResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
+    @retry_policy(
+        max_retry_count=4,
+        max_retry_interval_seconds=10,
+        retryable_exceptions=[ServerError],
+    )
     async def _get_page(
         self,
         user_uuid: str,
@@ -74,8 +50,11 @@ class BaseTransactionsResource(ABC):
                 ),
             )
 
+        if response.status_code == 500:
+            raise ServerError(response.text)
+
         assert response.status_code == 200, response.text
-        return TransactionsResponse(**response.json())
+        return response.json()  # type: ignore
 
     @validate_arguments
     @cache
@@ -98,7 +77,7 @@ class BaseTransactionsResource(ABC):
             account_types=account_types,
             page=page or 1,
         )
-        max_pages = response.meta.max_pages
+        max_pages = response["_meta"]["max_pages"]
         if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
@@ -120,8 +99,8 @@ class BaseTransactionsResource(ABC):
         return [
             record
             for response in responses
-            for transaction_account in response.transactions
-            for record in transaction_account.records
+            for transaction_account in response["transactions"]
+            for record in transaction_account["records"]
         ]
 
 
