@@ -1,56 +1,32 @@
 import asyncio
 from abc import ABC
 from datetime import datetime
-from typing import List, Optional
+from typing import Any, Dict, List, Optional
 
-from pydantic import BaseModel, validate_arguments
+from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
+from .errors import ServerError
+from .retry import retry_policy
 
 PATH = "/users"
 
-
-class User(BaseModel):
-    uuid: str
-    first_name: str
-    last_name: str
-    email: str
-    primary_phone_number: str
-    primary_phone_imei: Optional[str]
-    secondary_phone_number: Optional[str]
-    secondary_phone_imei: Optional[str]
-    is_kyc_verified: bool
-    device_id: str
-    external_id: Optional[str]
-    created_at: datetime
-    updated_at: datetime
-    country_code: str
-
-
-class UsersMeta(BaseModel):
-    client_uuid: str
-    created_before: datetime
-    created_after: datetime
-    search: str
-    total_users_count: int
-    page: int
-    max_pages: int
-
-
-class UsersResponse(BaseModel):
-    meta: UsersMeta
-    users: List[User]
-
-    class Config:
-        fields = {"meta": "_meta"}
+User = Dict[str, Any]
+UsersMeta = Dict[str, Any]
+UsersResponse = Dict[str, Any]
 
 
 class BaseUsersResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
+    @retry_policy(
+        max_retry_count=4,
+        max_retry_interval_seconds=10,
+        retryable_exceptions=[ServerError],
+    )
     async def _get_page(
         self,
         created_after: Optional[datetime] = None,
@@ -69,8 +45,11 @@ class BaseUsersResource(ABC):
                 ),
             )
 
+        if response.status_code == 500:
+            raise ServerError(response.text)
+
         assert response.status_code == 200, response.text
-        return UsersResponse(**response.json())
+        return response.json()  # type: ignore
 
     @validate_arguments
     @cache
@@ -85,7 +64,7 @@ class BaseUsersResource(ABC):
             created_before=created_before,
             search=search,
         )
-        max_pages = response.meta.max_pages
+        max_pages = response["_meta"]["max_pages"]
         if max_pages > 1:
             coroutines = [
                 self._get_page(
@@ -101,7 +80,7 @@ class BaseUsersResource(ABC):
         else:
             responses = (response,)
 
-        return [user for response in responses for user in response.users]
+        return [user for response in responses for user in response["users"]]
 
 
 class AsyncUsersResource(BaseUsersResource):
